﻿using SushiBarBusinessLogic;
using SushiBarContracts.BindingModels;

namespace SushiBarView.Forms
{
    public partial class FormCooks : Form
    {
        private readonly CookLogic _logic;

        public FormCooks(CookLogic Logic)
        {
            InitializeComponent();
            _logic = Logic;
        }

        private void FormCooks_Load(object sender, EventArgs e)
        {
            LoadData();
        }

        private void LoadData()
        {
            try
            {
                var List = _logic.ReadList(null);

                if (List != null)
                {
                    DataGridView.DataSource = List;
                    DataGridView.Columns["Id"].Visible = false;
                    DataGridView.Columns["Fio"].AutoSizeMode = DataGridViewAutoSizeColumnMode.Fill;
                    DataGridView.Columns["EmploymentDate"].AutoSizeMode = DataGridViewAutoSizeColumnMode.Fill;
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        private void AddButton_Click(object sender, EventArgs e)
        {
            FormCook Form = new FormCook(new CookLogic(new SushiBarDatabaseImplement.Storages.CookStorage()));

            if (Form.ShowDialog() == DialogResult.OK)
            {
                LoadData();
            }
        }

        private void ChangeButton_Click(object sender, EventArgs e)
        {
            if (DataGridView.SelectedRows.Count == 1)
            {
                FormCook Form = new FormCook(new CookLogic(new SushiBarDatabaseImplement.Storages.CookStorage()));
                Form.Id = Convert.ToInt32(DataGridView.SelectedRows[0].Cells["Id"].Value);

                if (Form.ShowDialog() == DialogResult.OK)
                {
                    LoadData();
                }
            }
        }

        private void DeleteButton_Click(object sender, EventArgs e)
        {
            if (DataGridView.SelectedRows.Count == 1)
            {
                if (MessageBox.Show("Удалить запись?", "Вопрос", MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.Yes)
                {
                    int id = Convert.ToInt32(DataGridView.SelectedRows[0].Cells["Id"].Value);

                    try
                    {
                        if (!_logic.Delete(new CookBindingModel
                        {
                            Id = id
                        }))
                        {
                            throw new Exception("Ошибка при удалении. Дополнительная информация в логах.");
                        }

                        LoadData();
                    }
                    catch (Exception ex)
                    {
                        MessageBox.Show(ex.Message, "Ошибка", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    }
                }
            }
        }

        private void RefreshButton_Click(object sender, EventArgs e)
        {
            LoadData();
        }
    }
}
